SanityDataset class

A class to represent a Sanity dataset.

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

SanityDataset({required String name, required String aclMode})
Creates a new Sanity dataset with the given name and ACL mode.
SanityDataset.fromJson(Map<String, dynamic> json)
Creates a new Sanity dataset from a JSON map.
factory

Properties

aclMode → String
The ACL mode of the dataset.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the dataset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override